@@ -25,15 +25,19 @@ static void read_nm_symbols(SYMBOL_SET *ss, const char *file, const OPTIONS *opt
     if (!regular_file(file, procname))
 	return;
 
-    cmd_strlen = strlen(path_nm)+1+strlen(nm_options)+strlen(options->target)+1+strlen(file)+1;
+    cmd_strlen = strlen(path_nm)+1 + strlen(file)+1;
+    if (options->target)
+	cmd_strlen += sizeof(nm_options) + strlen(options->target) + 1;
     cmd = malloc(cmd_strlen);
     if (!cmd)
 	malloc_error("nm command");
     strcpy(cmd, path_nm);
     strcat(cmd, " ");
-    strcat(cmd, nm_options);
-    strcat(cmd, options->target);
-    strcat(cmd, " ");
+    if (options->target) {
+	strcat(cmd, nm_options);
+	strcat(cmd, options->target);
+	strcat(cmd, " ");
+    }
     strcat(cmd, file);
     DEBUG(2, "command '%s'", cmd);
     if (!(f = popen_local(cmd, procname)))
